export type RenderCredits = {
    "version": "0.1.2";
    "name": "render_credits";
    "instructions": [
        {
            "name": "initializeRenderCreditsV0";
            "accounts": [
                {
                    "name": "renderCredits";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "rc";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rc_mint";
                            }
                        ];
                    };
                },
                {
                    "name": "rndrPriceOracle";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "mint_windowed_breaker";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rc_mint";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "circuit_breaker_program";
                        };
                    };
                },
                {
                    "name": "rcMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "mintAuthority";
                    "isMut": false;
                    "isSigner": true;
                },
                {
                    "name": "freezeAuthority";
                    "isMut": false;
                    "isSigner": true;
                },
                {
                    "name": "accountPayer";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "account_payer";
                            }
                        ];
                    };
                },
                {
                    "name": "payer";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "InitializeRenderCreditsArgsV0";
                    };
                }
            ];
        },
        {
            "name": "mintRenderCreditsV0";
            "accounts": [
                {
                    "name": "renderCredits";
                    "isMut": false;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "rc";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rc_mint";
                            }
                        ];
                    };
                    "relations": [
                        "rndr_mint",
                        "rc_mint",
                        "rndr_price_oracle"
                    ];
                },
                {
                    "name": "burnRewardsVoucher";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "emissionSchedule";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "emission_schedule";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rndr_mint";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "emission_schedule_program";
                        };
                    };
                },
                {
                    "name": "emissionScheduleProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrPriceOracle";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "burner";
                    "isMut": true;
                    "isSigner": false;
                    "relations": [
                        "owner"
                    ];
                },
                {
                    "name": "recipientTokenAccount";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "recipient";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "owner";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "rcMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "mint_windowed_breaker";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rc_mint";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "circuit_breaker_program";
                        };
                    };
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "associatedTokenProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "MintRenderCreditsArgsV0";
                    };
                }
            ];
        },
        {
            "name": "burnRenderCreditsV0";
            "accounts": [
                {
                    "name": "renderCredits";
                    "isMut": false;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "rc";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rc_mint";
                            }
                        ];
                    };
                    "relations": [
                        "rc_mint"
                    ];
                },
                {
                    "name": "burner";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "owner";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "rcMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "associatedTokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "BurnRenderCreditsArgsV0";
                    };
                }
            ];
        },
        {
            "name": "updateRenderCreditsV0";
            "accounts": [
                {
                    "name": "renderCredits";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "rc";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rc_mint";
                            }
                        ];
                    };
                    "relations": [
                        "authority"
                    ];
                },
                {
                    "name": "rcMint";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "authority";
                    "isMut": false;
                    "isSigner": true;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "UpdateRenderCreditsArgsV0";
                    };
                }
            ];
        },
        {
            "name": "initializeBurnRewardsV0";
            "accounts": [
                {
                    "name": "emissionSchedule";
                    "isMut": false;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "emission_schedule";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rndr_mint";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "emission_schedule_program";
                        };
                    };
                },
                {
                    "name": "emissionScheduleProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "transferer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "account_windowed_breaker";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "TokenAccount";
                                "path": "escrow";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "circuit_breaker_program";
                        };
                    };
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "owner";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "to";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "escrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "thread";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "thread";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "path": "owner";
                            },
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "receive_rewards";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "clockwork";
                        };
                    };
                },
                {
                    "name": "clockwork";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "burnRewardsVoucher";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "associatedTokenProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "InitializeBurnRewardsArgsV0";
                    };
                }
            ];
        },
        {
            "name": "distributeBurnRewardsV0";
            "accounts": [
                {
                    "name": "emissionSchedule";
                    "isMut": false;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "emission_schedule";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "Mint";
                                "path": "rndr_mint";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "emission_schedule_program";
                        };
                    };
                },
                {
                    "name": "emissionScheduleReceipt";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "emissionScheduleProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "to";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "escrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "account_windowed_breaker";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "TokenAccount";
                                "path": "escrow";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "circuit_breaker_program";
                        };
                    };
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "transferer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "thread";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "owner";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "burnRewardsVoucher";
                    "isMut": true;
                    "isSigner": false;
                }
            ];
            "args": [];
            "returns": {
                "defined": "clockwork_sdk::state::ThreadResponse";
            };
        },
        {
            "name": "initializeTransfererV0";
            "accounts": [
                {
                    "name": "transferer";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "circuitBreaker";
                    "isMut": true;
                    "isSigner": false;
                    "pda": {
                        "seeds": [
                            {
                                "kind": "const";
                                "type": "string";
                                "value": "account_windowed_breaker";
                            },
                            {
                                "kind": "account";
                                "type": "publicKey";
                                "account": "TokenAccount";
                                "path": "escrow";
                            }
                        ];
                        "programId": {
                            "kind": "account";
                            "type": "publicKey";
                            "path": "circuit_breaker_program";
                        };
                    };
                },
                {
                    "name": "circuitBreakerProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "escrow";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "escrowOwner";
                    "isMut": true;
                    "isSigner": true;
                },
                {
                    "name": "rndrMint";
                    "isMut": true;
                    "isSigner": false;
                },
                {
                    "name": "systemProgram";
                    "isMut": false;
                    "isSigner": false;
                },
                {
                    "name": "tokenProgram";
                    "isMut": false;
                    "isSigner": false;
                }
            ];
            "args": [
                {
                    "name": "args";
                    "type": {
                        "defined": "InitializeTransfererArgsV0";
                    };
                }
            ];
        }
    ];
    "accounts": [
        {
            "name": "renderCreditsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "rcMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "rndrMint";
                        "type": "publicKey";
                    },
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "rndrPriceOracle";
                        "type": "publicKey";
                    },
                    {
                        "name": "renderCreditsBump";
                        "type": "u8";
                    },
                    {
                        "name": "accountPayer";
                        "type": "publicKey";
                    },
                    {
                        "name": "accountPayerBump";
                        "type": "u8";
                    }
                ];
            };
        },
        {
            "name": "transfererV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "bump";
                        "type": "u8";
                    }
                ];
            };
        },
        {
            "name": "burnRewardsVoucherV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "epochId";
                        "type": "u64";
                    },
                    {
                        "name": "rndrBurned";
                        "type": "u64";
                    },
                    {
                        "name": "bump";
                        "type": "u8";
                    }
                ];
            };
        }
    ];
    "types": [
        {
            "name": "WindowedCircuitBreakerConfigV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "windowSizeSeconds";
                        "type": "u64";
                    },
                    {
                        "name": "thresholdType";
                        "type": {
                            "defined": "ThresholdType";
                        };
                    },
                    {
                        "name": "threshold";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "BurnRenderCreditsArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "amount";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "DistributeBurnRewardsArgsV0";
            "type": {
                "kind": "struct";
                "fields": [];
            };
        },
        {
            "name": "InitializeBurnRewardsArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "schedule";
                        "type": {
                            "option": "string";
                        };
                    }
                ];
            };
        },
        {
            "name": "InitializeBurnRewardsVoucherArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "epochId";
                        "type": "u64";
                    },
                    {
                        "name": "rcBurned";
                        "type": "u64";
                    },
                    {
                        "name": "rewardsClaimed";
                        "type": "u64";
                    }
                ];
            };
        },
        {
            "name": "InitializeRenderCreditsArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    },
                    {
                        "name": "config";
                        "type": {
                            "defined": "WindowedCircuitBreakerConfigV0";
                        };
                    }
                ];
            };
        },
        {
            "name": "InitializeTransfererArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "authority";
                        "type": "publicKey";
                    }
                ];
            };
        },
        {
            "name": "MintRenderCreditsArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "rndrAmount";
                        "type": {
                            "option": "u64";
                        };
                    },
                    {
                        "name": "rcAmount";
                        "type": {
                            "option": "u64";
                        };
                    }
                ];
            };
        },
        {
            "name": "UpdateRenderCreditsArgsV0";
            "type": {
                "kind": "struct";
                "fields": [
                    {
                        "name": "newAuthority";
                        "type": {
                            "option": "publicKey";
                        };
                    },
                    {
                        "name": "rndrPriceOracle";
                        "type": {
                            "option": "publicKey";
                        };
                    }
                ];
            };
        },
        {
            "name": "ThresholdType";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "Percent";
                    },
                    {
                        "name": "Absolute";
                    }
                ];
            };
        },
        {
            "name": "BurnRewardsErrors";
            "type": {
                "kind": "enum";
                "variants": [
                    {
                        "name": "MissingBurnRewards";
                    },
                    {
                        "name": "MissingEmissionSchedule";
                    },
                    {
                        "name": "CalculatingRewards";
                    },
                    {
                        "name": "BurnRewardsClaimed";
                    }
                ];
            };
        }
    ];
    "errors": [
        {
            "code": 6000;
            "name": "BumpNotAvailable";
            "msg": "Bump couldn't be found";
        },
        {
            "code": 6001;
            "name": "PythError";
            "msg": "Error loading Pyth data";
        },
        {
            "code": 6002;
            "name": "PythPriceNotFound";
            "msg": "Pyth price is not available";
        },
        {
            "code": 6003;
            "name": "PythPriceFeedStale";
            "msg": "Pyth price is stale";
        },
        {
            "code": 6004;
            "name": "ArithmeticError";
            "msg": "Arithmetic error";
        },
        {
            "code": 6005;
            "name": "InvalidArgs";
            "msg": "Invalid arguments";
        },
        {
            "code": 6006;
            "name": "NoGenesis";
            "msg": "Genesis endpoints are currently disabled";
        }
    ];
};
export declare const IDL: RenderCredits;
//# sourceMappingURL=render_credits.d.ts.map